from typing import List, Optional

from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.student import Student
from app.schemas.student import StudentCreate, StudentUpdate


class CRUDStudent(CRUDBase[Student, StudentCreate, StudentUpdate]):
    def get_by_student_id(self, db: Session, *, student_id: str) -> Optional[Student]:
        return db.query(Student).filter(Student.student_id == student_id).first()
    
    def get_by_user_id(self, db: Session, *, user_id: int) -> Optional[Student]:
        return db.query(Student).filter(Student.user_id == user_id).first()
    
    def get_by_grade_level(self, db: Session, *, grade_level: str) -> List[Student]:
        return db.query(Student).filter(Student.grade_level == grade_level).all()


student = CRUDStudent(Student)